@@ -9,6 +9,7 @@ class PayParams(object):
 
     def __init__(self):
         self._async_type = None
+        self._retry_type = None
 
     @property
     def async_type(self):
@@ -17,6 +18,13 @@ class PayParams(object):
     @async_type.setter
     def async_type(self, value):
         self._async_type = value
+    @property
+    def retry_type(self):
+        return self._retry_type
+
+    @retry_type.setter
+    def retry_type(self, value):
+        self._retry_type = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class PayParams(object):
                 params['async_type'] = self.async_type.to_alipay_dict()
             else:
                 params['async_type'] = self.async_type
+        if self.retry_type:
+            if hasattr(self.retry_type, 'to_alipay_dict'):
+                params['retry_type'] = self.retry_type.to_alipay_dict()
+            else:
+                params['retry_type'] = self.retry_type
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class PayParams(object):
         o = PayParams()
         if 'async_type' in d:
             o.async_type = d['async_type']
+        if 'retry_type' in d:
+            o.retry_type = d['retry_type']
         return o
 
 
