@@ -4,6 +4,7 @@ import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
 from alipay.aop.api.domain.DepositBackInfo import DepositBackInfo
+from alipay.aop.api.domain.EnterprisePayInfo import EnterprisePayInfo
 from alipay.aop.api.domain.TradeFundBill import TradeFundBill
 from alipay.aop.api.domain.RefundRoyaltyResult import RefundRoyaltyResult
 
@@ -13,6 +14,7 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
     def __init__(self):
         super(AlipayTradeFastpayRefundQueryResponse, self).__init__()
         self._deposit_back_info = None
+        self._enterprise_pay_info = None
         self._error_code = None
         self._gmt_refund_pay = None
         self._industry_sepc_detail = None
@@ -26,6 +28,7 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
         self._refund_channel_status = None
         self._refund_charge_amount = None
         self._refund_detail_item_list = None
+        self._refund_hyb_amount = None
         self._refund_reason = None
         self._refund_royaltys = None
         self._refund_settlement_id = None
@@ -45,6 +48,16 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
         else:
             self._deposit_back_info = DepositBackInfo.from_alipay_dict(value)
     @property
+    def enterprise_pay_info(self):
+        return self._enterprise_pay_info
+
+    @enterprise_pay_info.setter
+    def enterprise_pay_info(self, value):
+        if isinstance(value, EnterprisePayInfo):
+            self._enterprise_pay_info = value
+        else:
+            self._enterprise_pay_info = EnterprisePayInfo.from_alipay_dict(value)
+    @property
     def error_code(self):
         return self._error_code
 
@@ -142,6 +155,13 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
                 else:
                     self._refund_detail_item_list.append(TradeFundBill.from_alipay_dict(i))
     @property
+    def refund_hyb_amount(self):
+        return self._refund_hyb_amount
+
+    @refund_hyb_amount.setter
+    def refund_hyb_amount(self, value):
+        self._refund_hyb_amount = value
+    @property
     def refund_reason(self):
         return self._refund_reason
 
@@ -201,6 +221,8 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
         response = super(AlipayTradeFastpayRefundQueryResponse, self).parse_response_content(response_content)
         if 'deposit_back_info' in response:
             self.deposit_back_info = response['deposit_back_info']
+        if 'enterprise_pay_info' in response:
+            self.enterprise_pay_info = response['enterprise_pay_info']
         if 'error_code' in response:
             self.error_code = response['error_code']
         if 'gmt_refund_pay' in response:
@@ -227,6 +249,8 @@ class AlipayTradeFastpayRefundQueryResponse(AlipayResponse):
             self.refund_charge_amount = response['refund_charge_amount']
         if 'refund_detail_item_list' in response:
             self.refund_detail_item_list = response['refund_detail_item_list']
+        if 'refund_hyb_amount' in response:
+            self.refund_hyb_amount = response['refund_hyb_amount']
         if 'refund_reason' in response:
             self.refund_reason = response['refund_reason']
         if 'refund_royaltys' in response:
